<?php namespace EscapeWork\Manager\Controllers;

use EscapeWork\Manager\Facades\Check;
use EscapeWork\Manager\Facades\UserPassword;
use EscapeWork\Manager\Facades\UserAuth;
use Illuminate\Routing\Controllers\Controller;
use App;
use View;
use Input;
use Msg;
use Redirect;
use Session;

class ManagerController extends Controller
{

    /**
     * The page for check the permissions
     *
     * @var  string
     */
    protected $permissionPage;

    public function __construct()
    {
        $this->user         = App::make('EscapeWork\Manager\Repositories\User\UserRepository');
        $this->userReminder = App::make('EscapeWork\Manager\Repositories\UserReminder\UserReminderRepository');
    }

    public function enableDefaultFilters($permissionPage)
    {
        $this->permissionPage = $permissionPage;

        $this->enableCreateFilter()
             ->enableShowFilter()
             ->enableUpdateFilter()
             ->enableDestroyFilter();
    }

    public function enableCreateFilter()
    {
        $permissionPage = $this->permissionPage;

        $this->beforeFilter(function() use($permissionPage)
        {
            Check::canOrFail($permissionPage, 'create');
        }, array('only' => array('create', 'store')));

        return $this;
    }

    public function enableUpdateFilter()
    {
        $permissionPage = $this->permissionPage;

        $this->beforeFilter(function() use($permissionPage)
        {
            Check::canOrFail($permissionPage, 'update');
        }, array('only' => array('edit', 'update')));

        return $this;
    }

    public function enableDestroyFilter()
    {
        $permissionPage = $this->permissionPage;

        $this->beforeFilter(function() use($permissionPage)
        {
            Check::canOrFail($permissionPage, 'destroy');
        }, array('only' => array('destroy')));

        return $this;
    }

    public function enableShowFilter()
    {
        $permissionPage = $this->permissionPage;

        $this->beforeFilter(function() use($permissionPage)
        {
            Check::canOrFail($permissionPage, 'read');
        }, array('only' => array('show')));

        return $this;
    }

    public function sendResetPassword()
    {
        $credentials = array(
            'email' => Input::get('email')
        );

        if (! $user = $this->user->getByEmail($credentials['email'])) {
            return Redirect::route('manager.login')
                    ->with('error', 'Este e-mail não está cadastrado no sistema');
        }

        UserPassword::remind($credentials, function($m)
        {
            $m->subject('Seu lembrete de senha');
        });

        return Redirect::route('manager.login')
            ->with('message', 'Foi enviado para o seu e-mail instruções para refazer a sua senha.');
    }

    public function getResetPassword($token)
    {

        if ( ! $this->userReminder = $this->userReminder->getByToken($token)) {
            return Redirect::route('manager.login')
                        ->with('error', 'Token enviado é incorreto. Verifique o link enviado ao seu e-mail e tente novamente.');
        }

        $view               = View::make('manager::users.reset');
        $view->userReminder = $this->userReminder;
        $view->token        = $token;

        return $view;
    }

    public function postResetPassword()
    {
        $credentials = array('email' => Input::get('email'));

        if (! $user = $this->user->getByEmail($credentials['email'])) {
            return Redirect::route('manager.login')
                    ->with('error', 'O e-mail digitado para refazer a sua senha não existe!');
        }

        return UserPassword::reset($credentials, function($user, $password)
        {
            $user->password = $password;
            $user->save();

            return Redirect::route('manager.login')
                    ->with('message', 'Sua senha foi alterada com sucesso! Faça o login agora.')
                    ->with('email', $user->email);
        });
    }
}
