<?php namespace EscapeWork\Manager\Controllers;

use EscapeWork\Manager\Repositories\User\UserRepository;
use EscapeWork\Manager\Repositories\Role\RoleRepository;
use EscapeWork\Manager\Facades\UserAuth;
use View;
use Input;
use Redirect;
use Msg;
use Config;
use Request;
use App;

class UserController extends ManagerController
{

    public function __construct(UserRepository $user, RoleRepository $role)
    {
        $this->user = $user;
        $this->role = $role;

        $this->enableDefaultFilters('usuarios');
    }

    public function index()
    {
        $view        = View::make('manager::users.index');
        $view->users = $this->user->all();

        return $view;
    }

    public function create()
    {
        Msg::setInfo('Inserindo um novo usuário');

        $this->user->fill(Input::old());

        $view       = View::make('manager::users.form');
        $view->user = $this->user;
        $view->role = $this->role;
        $view->edit = false;

        return $view;
    }

    public function store()
    {
        $this->user->fill(Input::all());

        if (! $this->user->validate()) {
            return Redirect::route('manager.users.create')
                    ->withInput()
                    ->withErrors($this->user->getValidationErrors());
        }

        $this->user->save();

        return Redirect::route('manager.users.index')
                ->with('message', 'O usuário <strong>' . $this->user->name . '</strong> foi inserido com sucesso!');
    }

    public function show($id)
    {
        if (Request::ajax()) {
            return $this->user->find($id);
        } else {
            return Redirect::route('manager.users.index');
        }
    }

    public function edit($id)
    {
        $this->user = $this->user->findOrFail($id);

        Msg::setInfo('Editando o usuário <strong>'.$this->user->name.'</strong>');

        $view              = View::make('manager::users.form');
        $view->edit        = true;
        $view->user        = $this->user;
        $view->role        = $this->role;
        $view->extraFields = Config::get('manager::extra_fields.User');

        return $view;
    }

    public function update($id)
    {
        $this->user = $this->user->findOrFail($id);
        $this->user->fill(Input::all());

        if (! $this->user->validate()) {
            return Redirect::route('manager.users.edit', $this->user->id)
                            ->withInput()
                            ->withErrors($this->user->getValidationErrors());
        }

        $this->user->save();

        return Redirect::route('manager.users.index')
                ->with('message', 'O usuário <strong>'. $this->user->name .'</strong> foi editado com sucesso!');
    }

    public function destroy($id)
    {
        $this->user = $this->user->findOrFail($id);

        # verificando se o usuário logado não está tentando se excluir
        if (UserAuth::check() && $this->user->id == UserAuth::user()->id) {
            return Redirect::route('manager.users.index')
                    ->with('error', '<strong>'.$this->user->name.'</strong>, não é possível excluir o seu próprio usuário');
        }

        $this->user->delete();

        return Redirect::route('manager.users.index')
                ->with('message', 'O usuário <strong>'.$this->user->name.'</strong> foi excluído com sucesso!');
    }
}
