<?php
/*
|--------------------------------------------------------------------------
| Rotas do pacote escapework/manager
|--------------------------------------------------------------------------
*/

# uses
use EscapeWork\Manager\Facades\UserAuth;

# route binds
Route::bind('user', function($id, $route)
{
    $user = App::make('UserRepository');
    if (! $user = $user->find($id)) {
        App::abort(404);
    }

    return $user;
});

# ==================================================================
# filtro de login do manager
# ==================================================================
Route::filter('manager.auth', function()
{
    if (UserAuth::guest()) {
        return Redirect::intended(route('manager.login'));
    }
});

Route::filter('manager.guest', function()
{
    if (UserAuth::check()) return Redirect::route('manager.home');
});


Route::group(array('prefix' => Config::get('manager::url')), function()
{
    # ==================================================================
    # login
    # ==================================================================
    Route::get('login', array('as' => 'manager.login', 'uses' => 'EscapeWork\Manager\Controllers\LoginController@index'));
    Route::post('login', 'EscapeWork\Manager\Controllers\LoginController@login');
    Route::get('logout', array('as' => 'manager.logout', 'uses' => 'EscapeWork\Manager\Controllers\LoginController@logout'));


    # ==================================================================
    # grupo que precisa de autenticação
    # ==================================================================
    Route::group(array('before' => 'manager.auth'), function()
    {
        # ==================================================================
        # home
        # ==================================================================
         Route::get('/', array('as' => 'manager.home', 'uses' => Config::get('manager::controllers.home')));

        # ==================================================================
        # usuários
        # ==================================================================
        Route::get('usuarios', array('as' => 'manager.users.index', 'uses' => 'EscapeWork\Manager\Controllers\UserController@index'));
        Route::get('usuarios/create', array('as' => 'manager.users.create', 'uses' => 'EscapeWork\Manager\Controllers\UserController@create'));
        Route::post('usuarios', array('as' => 'manager.users.store', 'uses' => 'EscapeWork\Manager\Controllers\UserController@store'));
        Route::get('usuarios/{id}', array('as' => 'manager.users.show', 'uses' => 'EscapeWork\Manager\Controllers\UserController@show'));
        Route::get('usuarios/{id}/edit', array('as' => 'manager.users.edit', 'uses' => 'EscapeWork\Manager\Controllers\UserController@edit'));
        Route::put('usuarios/{id}', array('as' => 'manager.users.update', 'uses' => 'EscapeWork\Manager\Controllers\UserController@update'));
        Route::delete('usuarios/{id}', array('as' => 'manager.users.destroy', 'uses' => 'EscapeWork\Manager\Controllers\UserController@destroy'));

        # ==================================================================
        # roles
        # ==================================================================
        Route::get('regras', array('as' => 'manager.roles.index', 'uses' => 'EscapeWork\Manager\Controllers\RoleController@index'));
        Route::get('regras/create', array('as' => 'manager.roles.create', 'uses' => 'EscapeWork\Manager\Controllers\RoleController@create'));
        Route::post('regras', array('as' => 'manager.roles.store', 'uses' => 'EscapeWork\Manager\Controllers\RoleController@store'));
        Route::get('regras/{id}/edit', array('as' => 'manager.roles.edit', 'uses' => 'EscapeWork\Manager\Controllers\RoleController@edit'));
        Route::put('regras/{id}', array('as' => 'manager.roles.update', 'uses' => 'EscapeWork\Manager\Controllers\RoleController@update'));
        Route::delete('regras/{id}', array('as' => 'manager.roles.destroy', 'uses' => 'EscapeWork\Manager\Controllers\RoleController@destroy'));

        # ==================================================================
        # pages
        # ==================================================================
        Route::get('paginas', array('as' => 'manager.pages.index', 'uses' => 'EscapeWork\Manager\Controllers\PageController@index'));
        Route::get('paginas/create', array('as' => 'manager.pages.create', 'uses' => 'EscapeWork\Manager\Controllers\PageController@create'));
        Route::post('paginas', array('as' => 'manager.pages.store', 'uses' => 'EscapeWork\Manager\Controllers\PageController@store'));
        Route::get('paginas/{id}/edit', array('as' => 'manager.pages.edit', 'uses' => 'EscapeWork\Manager\Controllers\PageController@edit'));
        Route::put('paginas/{id}', array('as' => 'manager.pages.update', 'uses' => 'EscapeWork\Manager\Controllers\PageController@update'));
        Route::delete('paginas/{id}', array('as' => 'manager.pages.destroy', 'uses' => 'EscapeWork\Manager\Controllers\PageController@destroy'));

        # ==================================================================
        # logs
        # ==================================================================
        Route::get('logs', array('as' => 'manager.logs.index', 'uses' => 'EscapeWork\Manager\Controllers\LogsController@index'));
        Route::get('logs/{log}', array('as' => 'manager.logs.show', 'uses' => 'EscapeWork\Manager\Controllers\LogsController@show'));
        Route::delete('logs/{log}', array('as' => 'manager.logs.destroy', 'uses' => 'EscapeWork\Manager\Controllers\LogsController@destroy'));
    });

    # apenas quando não está logado
    Route::group(array('before' => 'manager.guest'), function()
    {
        # esqueci minha senha
        Route::get('esqueci-minha-senha', function()
        {
            return Redirect::route('manager.login');
        });

        Route::post('esqueci-minha-senha', array('as' => 'manager.usuarios.forgot.send', 'uses' => 'EscapeWork\Manager\Controllers\ManagerController@sendResetPassword'));
        Route::get('esqueci-minha-senha/reset/{token}', array('as'   => 'manager.password.reset', 'uses' => 'EscapeWork\Manager\Controllers\ManagerController@getResetPassword'));
        Route::post('esqueci-minha-senha/reset', array('as' => 'manager.usuarios.reset.update', 'uses' => 'EscapeWork\Manager\Controllers\ManagerController@postResetPassword'));
    });
});
